@@ -10,11 +10,11 @@ use warnings;
 use parent qw/ Plack::Middleware /;
 
 use Plack::Util;
-use Plack::Util::Accessor qw/ client sample_rate /;
+use Plack::Util::Accessor qw/ client /;
 use POSIX ();
 use Time::HiRes;
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.2.1';
 
 sub call {
     my ( $self, $env ) = @_;
@@ -32,32 +32,30 @@ sub call {
 
             return unless $client;
 
+            my $histogram = $client->can('timing') // $client->can('timing_ms');
+
             my $elapsed = Time::HiRes::tv_interval($start);
 
-            my $rate = $self->sample_rate // 1;
-
-            $client->timing_ms( 'psgi.response.time',
-                POSIX::ceil( $elapsed * 1000 ), $rate );
+            $client->$histogram( 'psgi.response.time',
+                POSIX::ceil( $elapsed * 1000 ) );
 
             if ( defined $env->{CONTENT_LENGTH} ) {
-                $client->timing_ms( 'psgi.request.content-length',
-                    $env->{CONTENT_LENGTH}, $rate );
+                $client->$histogram( 'psgi.request.content-length',
+                    $env->{CONTENT_LENGTH} );
             }
 
             if ( my $method = $env->{REQUEST_METHOD} ) {
-                $client->increment( 'psgi.request.method.' . $method, $rate );
+                $client->increment( 'psgi.request.method.' . $method );
             }
 
             if ( my $type = $env->{CONTENT_TYPE} ) {
                 $type =~ s#/#.#g;
                 $type =~ s/;.*$//;
-                $client->increment( 'psgi.request.content-type.' . $type,
-                    $rate );
+                $client->increment( 'psgi.request.content-type.' . $type );
 
             }
 
-            $client->set_add( 'psgi.request.remote_addr', $env->{REMOTE_ADDR},
-                $rate )
+            $client->set_add( 'psgi.request.remote_addr', $env->{REMOTE_ADDR} )
               if $env->{REMOTE_ADDR};
 
             my $h = Plack::Util::headers( $res->[1] );
@@ -68,23 +66,21 @@ sub call {
               || 'X-Sendfile';
 
             if ( $h->exists($xsendfile) ) {
-                $client->increment( 'psgi.response.x-sendfile', $rate );
+                $client->increment('psgi.response.x-sendfile');
             }
 
             if ( $h->exists('Content-Length') ) {
                 my $length = $h->get('Content-Length') || 0;
-                $client->timing_ms( 'psgi.response.content-length',
-                    $length, $rate );
+                $client->$histogram( 'psgi.response.content-length', $length );
             }
 
             if ( my $type = $h->get('Content-Type') ) {
                 $type =~ s#/#.#g;
                 $type =~ s/;.*$//;
-                $client->increment( 'psgi.response.content-type.' . $type,
-                    $rate );
+                $client->increment( 'psgi.response.content-type.' . $type );
             }
 
-            $client->increment( 'psgi.response.status.' . $res->[0], $rate );
+            $client->increment( 'psgi.response.status.' . $res->[0] );
 
             if (
                   $env->{'psgix.harakiri.supported'}
@@ -92,9 +88,11 @@ sub call {
                 : $env->{'psgix.harakiri.commit'}
               )
             {
-                $client->increment( 'psgix.harakiri', $rate );
+                $client->increment('psgix.harakiri');
             }
 
+            $client->flush if $client->can('flush');
+
             return;
         }
     );
@@ -116,7 +114,7 @@ Plack::Middleware::Statsd - send statistics to statsd
 
 =head1 VERSION
 
-version v0.2.0
+version v0.2.1
 
 =head1 SYNOPSIS
 
@@ -126,8 +124,7 @@ version v0.2.0
   builder {
 
     enable "Statsd",
-      client      => Net::Statsd::Client->new( ... ),
-      sample_rate => 1.0;
+      client      => Net::Statsd::Client->new( ... );
 
     ...
 
@@ -165,41 +162,27 @@ C<psgix.monitor.statsd> will be set to the current client if it is not
 set.
 
 The only restriction on the client is that it has the same API as
-L<Net::Statsd::Client> by supporting the following methods:
+L<Net::Statsd::Client> or similar modules, by supporting the following
+methods:
 
 =over
 
 =item
 
-update
+C<increment>
 
 =item
 
-increment
+C<timing_ms> or C<timing>
 
 =item
 
-decrement
-
-=item
-
-timing_ms
-
-=item
-
-set_add
+C<set_add>
 
 =back
 
 Other statsd client modules may be used via a wrapper class.
 
-=head2 sample_rate
-
-The default sampling rate to used. This will override the default rate
-of the L</client>.
-
-It defaults to C<1>.
-
 =head1 METRICS
 
 The following metrics are logged:
@@ -268,10 +251,30 @@ This counter is incremented when the harakiri flag is set.
 If you want to rename these, then you will need to use a wrapper
 class for the L</client>.
 
+=head1 EXAMPLES
+
+=head2 Using from Catalyst
+
+You can access the configured statsd client from L<Catalyst>:
+
+  sub finalize {
+    my $c = shift;
+
+    if (my $statsd = $c->req->env->{'psgix.monitor.statsd'}) {
+      ...
+
+
+    }
+
+    $c->next::method(@_);
+  }
+
 =head1 SEE ALSO
 
 L<Net::Statsd::Client>
 
+L<Net::Statsd::Tiny>
+
 L<PSGI>
 
 =head1 SOURCE
